Welcome to the Scikit-HEP project! — Scikit-HEP 0.0.1 documentation

# Welcome to the Scikit-HEP project!

You can find a little introduction to the project in the About page. To get started, first install the skhep module and then read the main documentation.

If you have ideas concerning the development of the project, or if there is a feature missing you’d like to see, you are most welcome to contribute to Scikit-HEP. Please also check out the list of affiliated packages.

## Indices and tables

- Index
- Module Index
- Search Page